@@ -1,33 +1,33 @@
 import inspect
 import traceback
-
 from functools import wraps
-from typing import Callable, Tuple, Dict, List, Any
-from meiga import Result, Error, Success
-from meiga.decorators import meiga
+from typing import Any, Callable, Dict, List, Tuple
 
-from petisco.event.bus.domain.interface_event_bus import IEventBus
+from meiga import Error, Result, Success
+from meiga.decorators import meiga
 from petisco.application.petisco import Petisco
+from petisco.controller.errors.http_error import HttpError
 from petisco.controller.errors.internal_http_error import InternalHttpError
 from petisco.controller.errors.known_result_failure_handler import (
     KnownResultFailureHandler,
 )
-
 from petisco.domain.aggregate_roots.info_id import InfoId
 from petisco.domain.errors.critical_error import CriticalError
-
+from petisco.event.bus.domain.interface_event_bus import IEventBus
 from petisco.event.shared.domain.request_responded import RequestResponded
 from petisco.frameworks.flask.flask_headers_provider import flask_headers_provider
-from petisco.logger.interface_logger import ERROR, DEBUG
-from petisco.controller.errors.http_error import HttpError
+from petisco.logger.interface_logger import DEBUG, ERROR
+from petisco.logger.log_message import LogMessage
 from petisco.notifier.domain.interface_notifier import INotifier
 from petisco.notifier.domain.notifier_exception_message import NotifierExceptionMessage
 from petisco.notifier.domain.notifier_message import NotifierMessage
+from petisco.persistence.elastic.apm_extension_is_installed import (
+    apm_extension_is_installed,
+)
 from petisco.security.token_manager.not_implemented_token_manager import (
     NotImplementedTokenManager,
 )
 from petisco.security.token_manager.token_manager import TokenManager
-from petisco.logger.log_message import LogMessage
 from petisco.tools.timer import timer
 
 DEFAULT_SUCCESS_MESSAGE = {"message": "OK"}, 200
@@ -53,6 +53,7 @@ class _ControllerHandler:
         logging_types_blacklist: List[Any] = [bytes],
         event_bus: IEventBus = DEFAULT_EVENT_BUS,
         send_request_responded_event: bool = False,
+        inject_apm_metadata: bool = False,
     ):
         """
         Parameters
@@ -79,6 +80,8 @@ class _ControllerHandler:
             A IEventBus implementation. If not specified it will get it from Petisco.get_event_bus().
         send_request_responded_event
             Boolean to select if RequestResponded event is send. It will use provided publisher
+        inject_apm_metadata
+            Boolean to inject info_id in metadata of current apm transaction.
         """
         self.app_name = app_name
         self.app_version = app_version
@@ -91,6 +94,7 @@ class _ControllerHandler:
         self.headers_provider = headers_provider
         self.logging_types_blacklist = logging_types_blacklist
         self.send_request_responded_event = send_request_responded_event
+        self.inject_apm_metadata = inject_apm_metadata
 
     def _check_app_name(self):
         if self.app_name == DEFAULT_ERROR_MESSAGE:
@@ -210,6 +214,15 @@ class _ControllerHandler:
 
                 self.event_bus.publish(request_responded)
 
+            if self.inject_apm_metadata and apm_extension_is_installed():
+                import elasticapm
+
+                elasticapm.label(
+                    client_id=info_id.to_dict()["client_id"],
+                    user_id=info_id.to_dict()["user_id"],
+                    correlation_id=info_id.to_dict()["correlation_id"],
+                )
+
             return http_response
 
         def add_headers(kwargs):
